@@ -4,7 +4,7 @@ from typing import List
 
 class Vector3:
 
-    epsilon = 0.001
+    epsilon = 0.03
 
     def __init__(self, x: float, y: float, z: float, _type: str = ''):
         self._type = 'vector3'
@@ -22,17 +22,21 @@ class Vector3:
     def __ne__(self, other: object) -> bool:
         return not self.__eq__(other)
 
+    def __sub__(self, other):
+        return Vector3(self.x - other.x, self.y - other.y, self.z - other.z)
+
     def __repr__(self):
         return f"Vector3<x={self.x}, y={self.y}, z={self.z}>"
 
 
 class Pose:
 
-    def __init__(self, position: Vector3, rotation: Vector3, name: str = '', _type: str = ''):
+    def __init__(self, position: Vector3, rotation: Vector3, name: str = '', axis_angle=None,  _type: str = ''):
         self._type = 'pose'
         self.name = name
         self.position = position
         self.rotation = rotation
+        self.axis_angle = AxisAngle.from_rotation_vec(rotation)
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Pose):
