@@ -30,3 +30,22 @@ class Process:
 
     def __repr__(self):
         return f"<id={self.uuid},name={self.name},tasks={self.tasks},description={self.description}>"
+
+
+class ProcessMessage:
+
+    def __init__(self, process_uuid: str, message: str, _type: str = ''):
+        self._type = 'process_message'
+        self.process_uuid = process_uuid
+        self.message = message
+
+    def __eq__(self, other: object) -> bool:
+        if isinstance(other, ProcessMessage):
+            return other.process_uuid == self.process_uuid and other.message == self.message
+        return False
+
+    def __ne__(self, other: object) -> bool:
+        return not self.__eq__(other)
+
+    def __repr__(self):
+        return f"<process_uuid={self.process_uuid},message={self.message}>"
