@@ -15,7 +15,7 @@ class Test(TestCase):
                           '"y": 0.0, "z": 0.0}, "rotation": {"_type": "vector3", "x": 0.0, "y": 0.0, "z": 0.0}' \
                           ', "axis_angle": {"_type": "axis_angle", "angle": 0.0, "x": 1, "y": 0, "z": 0}}, ' \
                           '"automated": false, "assigned_to": "human", "conditions": [], "conditions_fulfilled": true, ' \
-                          '"description": "", "status": "waiting"}'
+                          '"can_undo": false, "description": "", "status": "waiting"}'
 
         self.assertIs(type(task_string), str, f"Got: {type(task_string)}. Expected {str}")
         self.assertEqual(task_string, expected_string, f"Expected {expected_string}, got: {task_string}")
